==> kube-integration-1.0.11.tgz: package/lib/kube-native/deployment/deploy.status.analyzer.js <==
'use strict';

const _ = require('lodash');

const Base = require('./../../status.analyzer.base');

class DeploymentStatusAnalyzer extends Base {

    /**
     * The deployment can have only 4/5 statuses
     * Success: when all the replicas are available and its the same number as required by deployment descriptor
     * Failed: when there are no replicas as all or when the some resource allocation
     * In Progress: during rollout or scale
     * Warning: Not exist in that case for now
     * Unknown: default fallback
     * For more information read: https://kubernetes.io/docs/concepts/workloads/controllers/deployment/#deployment-status
     */
    analyze() {
        const conditions  = _.get(this, '_status.conditions', []);
        this._finalStauts = Base.types.unknown;

        const readyReplicas       = _.get(this, '_status.readyReplicas');
        const availableReplicas   = _.get(this, '_status.availableReplicas');
        const totalReplicas       = _.get(this, '_status.replicas');
        const unavailableReplicas = _.get(this, '_status.unavailableReplicas');

        if (!_.isNumber(totalReplicas) || !_.isNumber(readyReplicas) ||
            !_.isNumber(availableReplicas)) {
            this._finalStauts = Base.types.unknown;
        }

        if (availableReplicas === totalReplicas && _.size(conditions) === 1 &&
            _.get(conditions, '[0].status', '') === 'True') {
            this._finalStauts = Base.types.suceess;
        }

        else if (availableReplicas === 0 &&
                 _.find(conditions, { type: 'ReplicaFailure', status: 'True' })) {
            this._finalStauts = Base.types.failed;
        }

        else {
            this._finalStauts = Base.types.inProgress;
        }

        return _.merge({}, this._finalStauts, {
            givenStatus: this._status,
            resouceType: this._resource
        });
    }


}


module.exports = DeploymentStatusAnalyzer;

==> kube-integration-1.21.0.tgz: package/lib/kube-native/deployment/deploy.status.analyzer.js <==
'use strict';

const _ = require('lodash');

const Base = require('./../../status.analyzer.base');

class DeploymentStatusAnalyzer extends Base {

    /**
     * The deployment can have only 4/5 statuses
     * Success: when all the replicas are available and its the same number as required by deployment descriptor
     * Failed: when there are no replicas as all or when the some resource allocation
     * In Progress: during rollout or scale
     * Warning: Not exist in that case for now
     * Unknown: default fallback
     * For more information read: https://kubernetes.io/docs/concepts/workloads/controllers/deployment/#deployment-status
     */
    analyze() {
        const conditions  = _.get(this, '_status.conditions', []);
        this._finalStauts = Base.types.unknown;

        const readyReplicas       = _.get(this, '_status.readyReplicas');
        const availableReplicas   = _.get(this, '_status.availableReplicas');
        const totalReplicas       = _.get(this, '_status.replicas');

        if (!_.isNumber(totalReplicas) || !_.isNumber(readyReplicas) ||
            !_.isNumber(availableReplicas)) {
            this._finalStauts = Base.types.unknown;
        }
        
        if (availableReplicas === totalReplicas && _.find(conditions, { type: 'Available', status: 'True' })) {
            this._finalStauts = Base.types.suceess;
        }

        else if (availableReplicas === 0 &&
                 _.find(conditions, { type: 'ReplicaFailure', status: 'True' })) {
            this._finalStauts = Base.types.failed;
        }

        else {
            this._finalStauts = Base.types.inProgress;
        }

        return _.merge({}, this._finalStauts, {
            givenStatus: this._status,
            resouceType: this._resource
        });
    }


}


module.exports = DeploymentStatusAnalyzer;
